@@ -88,7 +88,7 @@ public:
 // user defined declarations:
 public:
 
-# 150 "/build/kdevelop-php/src/kdev-php-23.08.3/parser/php.g" 1
+# 150 "/build/kdevelop-php/src/kdev-php-24.02.1/parser/php.g" 1
 
     /**
      * Transform the raw input into tokens.
@@ -132,7 +132,7 @@ public:
 
 private:
 
-# 189 "/build/kdevelop-php/src/kdev-php-23.08.3/parser/php.g" 1
+# 189 "/build/kdevelop-php/src/kdev-php-24.02.1/parser/php.g" 1
 
     enum VarExpressionState
     {
@@ -177,7 +177,7 @@ public:
 
 // user defined constructor code:
 
-# 210 "/build/kdevelop-php/src/kdev-php-23.08.3/parser/php.g" 1
+# 210 "/build/kdevelop-php/src/kdev-php-24.02.1/parser/php.g" 1
 
         m_state.varExpressionState = Normal;
         m_state.varExpressionIsVariable = false;
@@ -280,6 +280,7 @@ public:
     bool parseParameter(ParameterAst **yynode);
     bool parseParameterList(ParameterListAst **yynode);
     bool parseParameterType(ParameterTypeAst **yynode);
+    bool parseParameterTypeHint(ParameterTypeHintAst **yynode);
     bool parsePostprefixOperator(PostprefixOperatorAst **yynode);
     bool parsePrintExpression(PrintExpressionAst **yynode);
     bool parsePropertyType(PropertyTypeAst **yynode);
@@ -289,6 +290,7 @@ public:
     bool parseReservedNonModifierIdentifier(ReservedNonModifierIdentifierAst **yynode);
     bool parseReservedNonModifiers(ReservedNonModifiersAst **yynode);
     bool parseReturnType(ReturnTypeAst **yynode);
+    bool parseReturnTypeHint(ReturnTypeHintAst **yynode);
     bool parseScalar(ScalarAst **yynode);
     bool parseSemiReserved(SemiReservedAst **yynode);
     bool parseSemiReservedIdentifier(SemiReservedIdentifierAst **yynode);
@@ -312,6 +314,9 @@ public:
     bool parseTraitVisibilityModifiers(TraitVisibilityModifiersAst **yynode);
     bool parseUnaryExpression(UnaryExpressionAst **yynode);
     bool parseUnaryExpressionNotPlusminus(UnaryExpressionNotPlusminusAst **yynode);
+    bool parseUnionParameterType(UnionParameterTypeAst **yynode);
+    bool parseUnionPropertyType(UnionPropertyTypeAst **yynode);
+    bool parseUnionReturnType(UnionReturnTypeAst **yynode);
     bool parseUseNamespaceOrUseGroupedNamespace(UseNamespaceOrUseGroupedNamespaceAst **yynode);
     bool parseUseStatement(UseStatementAst **yynode);
     bool parseVarExpression(VarExpressionAst **yynode);
